@@ -942,6 +942,7 @@ pci_system_netbsd_create(void)
 		for (i = 0; i < nbuses; i++)
 			close(buses[i].fd);
 		free(pci_sys);
+		pci_sys = NULL;
 		return ENOMEM;
 	}
 
@@ -959,6 +960,10 @@ pci_system_netbsd_create(void)
 					continue;
 
 				device->base.domain = domain;
+				if (domain > 0xffff)
+				    device->base.domain_16 = 0xffff;
+				else
+				    device->base.domain_16 = domain & 0xffff;
 				device->base.bus = bus;
 				device->base.dev = dev;
 				device->base.func = func;
